@@ -24,6 +24,7 @@
 #include "Consumer.h"
 #include "Client.h"
 #include "Reader.h"
+#include "CryptoKeyReader.h"
 #include <napi.h>
 
 Napi::Object InitAll(Napi::Env env, Napi::Object exports) {
@@ -33,6 +34,7 @@ Napi::Object InitAll(Napi::Env env, Napi::Object exports) {
   Producer::Init(env, exports);
   Consumer::Init(env, exports);
   Reader::Init(env, exports);
+  CryptoKeyReader::Init(env, exports);
   return Client::Init(env, exports);
 }
 
